@@ -1,3 +1,6 @@
+import pytest
+
+from cardbuilder.common.config import Config
 from cardbuilder.common.languages import ENGLISH
 from cardbuilder.input.word import Word
 from cardbuilder.lookup.data_source import DataSource
@@ -5,6 +8,7 @@ from cardbuilder.lookup.en_to_ja.eijiro import Eijiro
 from tests.lookup.data_source_test import DataSourceTest
 
 
+@pytest.mark.skipif(not Config.has(Eijiro.eijiro_conf_value), reason="Requires Eijiro data to be loaded")
 class TestEijiro(DataSourceTest):
     def get_data_source(self) -> DataSource:
         return Eijiro()
@@ -17,5 +21,8 @@ class TestEijiro(DataSourceTest):
         little_result = data_source.lookup_word(Word('little', ENGLISH), 'little')  # has unmarked link
         number_result = data_source.lookup_word(Word('number', ENGLISH), 'number')  # has grouped links
 
+        # stanch and staunch form a link cycle, we test to make sure that doesn't cause problems
+        stanch_result = data_source.lookup_word(Word('stanch', ENGLISH), 'stanch')
+
         print('debug')
         #TODO: flesh out this test, add a test for words with links (previously caused problems)
